@@ -30,6 +30,9 @@ urlpatterns = patterns('tendenci.addons.corporate_memberships.views',
     url(r"^applications/search/$",
         "corpmembership_search",
         name="corpmembership.search"),
+    url(r"^applications/pendings/$",
+        "corpmembership_search", {'pending_only': True},
+        name="corpmembership.pending_list"),
     url(r"^applications/mycorps/$",
         "corpmembership_search", {'my_corps_only': True},
         name="corpmembership.mycorps"),
