@@ -20,8 +20,7 @@ from tendenci.addons.events.models import (
     Event, Place, RegistrationConfiguration, Payment,
     Sponsor, Organizer, Speaker, Type, TypeColorSet,
     RegConfPricing, Addon, AddonOption, CustomRegForm,
-    CustomRegField, CustomRegFormEntry, CustomRegFieldEntry,
-    Registrant
+    CustomRegField, CustomRegFormEntry, CustomRegFieldEntry
 )
 
 from form_utils.forms import BetterModelForm
@@ -30,16 +29,11 @@ from tendenci.core.payments.models import PaymentMethod
 from tendenci.core.perms.forms import TendenciBaseForm
 from tendenci.core.base.fields import SplitDateTimeField, EmailVerificationField
 from tendenci.core.emails.models import Email
-from tendenci.core.site_settings.utils import get_setting
-from tendenci.core.imports.utils import get_header_list_from_content
-from tendenci.core.imports.models import Import
-from form_utils.forms import BetterModelForm
+from tendenci.core.site_settings.utils import get_setting, get_global_setting
 from tendenci.apps.user_groups.models import Group
 from tendenci.apps.discounts.models import Discount
 from tendenci.apps.profiles.models import Profile
 from tendenci.addons.events.settings import FIELD_MAX_LENGTH
-from tendenci.core.site_settings.utils import get_setting
-from tendenci.addons.memberships.models import Membership
 
 from fields import Reg8nDtField, UseCustomRegField
 from widgets import UseCustomRegWidget
@@ -503,9 +497,7 @@ class EventForm(TendenciBaseForm):
             self.fields['description'].widget.mce_attrs['app_instance_id'] = self.instance.pk
         else:
             self.fields['description'].widget.mce_attrs['app_instance_id'] = 0
-            group = Group.objects.first(**{'entity_id': 1})
-            if group:
-                self.fields['group'].initial = group.pk
+            self.fields['group'].initial = Group.objects.get_initial_group_id()
 
         if self.instance.image:
             self.fields['photo_upload'].help_text = '<input name="remove_photo" id="id_remove_photo" type="checkbox"/> Remove current image: <a target="_blank" href="/files/%s/">%s</a>' % (self.instance.image.pk, basename(self.instance.image.file.name))
